@@ -1,8 +1,11 @@
 """
 """
 
+# mypy: ignore-errors
+
 # stdlib
 from datetime import date
+from typing import List
 
 # module
 from avwx.current.base import Reports
@@ -11,8 +14,7 @@ from avwx.structs import AirepData
 
 
 def parse(report: str, issued: date = None) -> AirepData:
-    """
-    """
+    """"""
     if not report:
         return None
     clean = sanitization.sanitize_report_string(report)
@@ -24,17 +26,13 @@ def parse(report: str, issued: date = None) -> AirepData:
 
 
 class Aireps(Reports):
-    """
-    Class to handle aircraft report data
-    """
+    """Class to handle aircraft report data"""
 
-    data: [AirepData] = None
+    data: List[AirepData] = None
 
     @staticmethod
-    def _report_filter(reports: [str]) -> [str]:
-        """
-        Removes PIREPs before updating raw_reports
-        """
+    def _report_filter(reports: List[str]) -> List[str]:
+        """Removes PIREPs before updating raw_reports"""
         return [r for r in reports if r.startswith("ARP")]
 
     def _post_update(self):
