@@ -6,6 +6,7 @@ Current report shared resources
 
 # stdlib
 from datetime import date
+from typing import List, Optional, Tuple, Union
 
 # module
 from avwx.base import AVWXBase
@@ -14,7 +15,7 @@ from avwx.static.core import NA_UNITS, WX_TRANSLATIONS
 from avwx.structs import Code, ReportData, ReportTrans, Units
 
 
-def wx_code(code: str) -> "Code/str":
+def wx_code(code: str) -> Union[Code, str]:
     """
     Translates weather codes into readable strings
 
@@ -41,14 +42,18 @@ def wx_code(code: str) -> "Code/str":
     return Code(code_copy, ret.strip())
 
 
-def get_wx_codes(codes: [str]) -> ([Code], [str]):
+def get_wx_codes(codes: List[str]) -> Tuple[List[str], List[Code]]:
     """
     Separates parsed WX codes
     """
-    ret, other = [], []
-    for code in codes:
-        code = wx_code(code)
-        (ret if isinstance(code, Code) else other).append(code)
+    other: List[str] = []
+    ret: List[Code] = []
+    for item in codes:
+        code = wx_code(item)
+        if isinstance(code, Code):
+            ret.append(code)
+        else:
+            other.append(code)
     return other, ret
 
 
@@ -58,13 +63,13 @@ class Report(AVWXBase):
     """
 
     #: ReportTrans dataclass of translation strings from data. Parsed on update()
-    translations: ReportTrans = None
+    translations: Optional[ReportTrans] = None
 
     def __init__(self, icao: str):
         super().__init__(icao)
-        self.service = get_service(icao, self.station.country)(
-            self.__class__.__name__.lower()
-        )
+        if self.station is not None:
+            service = get_service(icao, self.station.country)
+            self.service = service(self.__class__.__name__.lower())  # type: ignore
 
 
 class Reports(AVWXBase):
@@ -72,15 +77,16 @@ class Reports(AVWXBase):
     Base class containing multiple reports
     """
 
-    raw: [str] = None
-    data: [ReportData] = None
+    raw: Optional[List[str]] = None  # type: ignore
+    data: Optional[List[ReportData]] = None  # type: ignore
     units: Units = Units(**NA_UNITS)
 
     def __init__(self, icao: str = None, lat: float = None, lon: float = None):
         if icao:
             super().__init__(icao)
-            lat = self.station.latitude
-            lon = self.station.longitude
+            if self.station is not None:
+                lat = self.station.latitude
+                lon = self.station.longitude
         elif lat is None or lon is None:
             raise ValueError("No station or valid coordinates given")
         self.lat = lat
@@ -91,54 +97,42 @@ class Reports(AVWXBase):
         return f"<avwx.{self.__class__.__name__} lat={self.lat} lon={self.lon}>"
 
     @staticmethod
-    def _report_filter(reports: [str]) -> [str]:
-        """
-        Applies any report filtering before updating raw_reports
-        """
+    def _report_filter(reports: List[str]) -> List[str]:
+        """Applies any report filtering before updating raw_reports"""
         return reports
 
+    def _update(  # type: ignore
+        self, reports: List[str], issued: Optional[date], disable_post: bool
+    ) -> bool:
+        if not reports:
+            return False
+        reports = self._report_filter(reports)
+        return super()._update(reports, issued, disable_post)
+
+    def parse(self, reports: Union[str, List[str]], issued: Optional[date] = None):
+        """Updates report data by parsing a given report
+
+        Can accept a report issue date if not a recent report string
+        """
+        if isinstance(reports, str):
+            reports = [reports]
+        return self._update(reports, issued, False)
+
     def update(
         self,
-        reports: [str] = None,
-        issued: date = None,
         timeout: int = 10,
         disable_post: bool = False,
     ) -> bool:
-        """
-        Updates raw and data by fetch recent aircraft reports
-
-        Can accept a list report strings to parse instead
+        """Updates report data by fetching and parsing the report
 
         Returns True if new reports are available, else False
         """
-        if not reports:
-            reports = self.service.fetch(lat=self.lat, lon=self.lon, timeout=timeout)
-            if not reports:
-                return False
-            issued = None
-        if isinstance(reports, str):
-            reports = [reports]
-        if reports == self.raw:
-            return False
-        self.raw = self._report_filter(reports)
-        self.issued = issued
-        if not disable_post:
-            self._post_update()
-        self._set_meta()
-        return True
+        reports = self.service.fetch(lat=self.lat, lon=self.lon, timeout=timeout)  # type: ignore
+        return self._update(reports, None, disable_post)
 
     async def async_update(self, timeout: int = 10, disable_post: bool = False) -> bool:
-        """
-        Async version of update
-        """
-        reports = await self.service.async_fetch(
+        """Async updates report data by fetching and parsing the report"""
+        reports = await self.service.async_fetch(  # type: ignore
             lat=self.lat, lon=self.lon, timeout=timeout
         )
-        if not reports or reports == self.raw:
-            return False
-        self.raw = reports
-        self.issued = None
-        if not disable_post:
-            self._post_update()
-        self._set_meta()
-        return True
+        return self._update(reports, None, disable_post)
