@@ -2,16 +2,18 @@
 Contains functions for handling and translating remarks
 """
 
+# stdlib
+from typing import Callable, Dict, Optional
+
 # module
 from avwx.parsing import core
 from avwx.static.core import REMARKS_ELEMENTS, REMARKS_GROUPS, WX_TRANSLATIONS
 from avwx.static.taf import PRESSURE_TENDENCIES
-from avwx.structs import RemarksData
+from avwx.structs import Number, RemarksData
 
 
-def _tdec(code: str, unit: str = "C") -> str:
-    """
-    Translates a 4-digit decimal temperature representation
+def _tdec(code: Optional[str], unit: Optional[str] = "C") -> Optional[str]:
+    """Translates a 4-digit decimal temperature representation
 
     Ex: 1045 -> -4.5°C    0237 -> 23.7°C
     """
@@ -24,16 +26,13 @@ def _tdec(code: str, unit: str = "C") -> str:
 
 
 def temp_minmax(code: str) -> str:
-    """
-    Translates a 5-digit min/max temperature code
-    """
+    """Translates a 5-digit min/max temperature code"""
     label = "maximum" if code[0] == "1" else "minimum"
     return f"6-hour {label} temperature {_tdec(code[1:])}"
 
 
 def pressure_tendency(code: str, unit: str = "mb") -> str:
-    """
-    Translates a 5-digit pressure outlook code
+    """Translates a 5-digit pressure outlook code
 
     Ex: 50123 -> 12.3 mb: Increasing, then decreasing
     """
@@ -45,9 +44,7 @@ def pressure_tendency(code: str, unit: str = "mb") -> str:
 
 
 def precip_36(code: str, unit: str = "in") -> str:
-    """
-    Translates a 5-digit 3 and 6-hour precipitation code
-    """
+    """Translates a 5-digit 3 and 6-hour precipitation code"""
     return (
         "Precipitation in the last 3 hours: "
         f"{int(code[1:3])} {unit}. - 6 hours: {int(code[3:])} {unit}."
@@ -55,20 +52,16 @@ def precip_36(code: str, unit: str = "in") -> str:
 
 
 def precip_24(code: str, unit: str = "in") -> str:
-    """
-    Translates a 5-digit 24-hour precipitation code
-    """
+    """Translates a 5-digit 24-hour precipitation code"""
     return f"Precipitation in the last 24 hours: {int(code[1:])} {unit}."
 
 
 def sunshine_duration(code: str, unit: str = "minutes") -> str:
-    """
-    Translates a 5-digit sunlight duration code
-    """
+    """Translates a 5-digit sunlight duration code"""
     return f"Duration of sunlight: {int(code[1:])} {unit}"
 
 
-LEN5_DECODE = {
+LEN5_DECODE: Dict[str, Callable] = {
     "1": temp_minmax,
     "2": temp_minmax,
     "5": pressure_tendency,
@@ -79,21 +72,25 @@ LEN5_DECODE = {
 
 
 def parse(rmk: str) -> RemarksData:
-    """
-    Finds temperature and dewpoint decimal values from the remarks
-    """
-    rmkdata = {}
+    """Finds temperature and dewpoint decimal values from the remarks"""
+    temperature_decimal: Optional[Number] = None
+    dewpoint_decimal: Optional[Number] = None
     for item in rmk.split():
         if len(item) in [5, 9] and item[0] == "T" and item[1:].isdigit():
-            rmkdata["temperature_decimal"] = core.make_number(_tdec(item[1:5], None))
-            rmkdata["dewpoint_decimal"] = core.make_number(_tdec(item[5:], None))
-    return RemarksData(**rmkdata)
+            temp = _tdec(item[1:5], None)
+            if temp is not None:
+                temperature_decimal = core.make_number(temp)
+            dew = _tdec(item[5:], None)
+            if dew is not None:
+                dewpoint_decimal = core.make_number(dew)
+            break
+    return RemarksData(dewpoint_decimal, temperature_decimal)
 
 
-def translate(remarks: str) -> {str: str}:
-    """
-    Translates elements in the remarks string
-    """
+def translate(remarks: Optional[str]) -> Dict[str, str]:
+    """Translates elements in the remarks string"""
+    if not remarks:
+        return {}
     ret = {}
     # Add and replace static multi-word elements
     for key in REMARKS_GROUPS:
