@@ -3,16 +3,21 @@ Contains functions for converting translations into a speech string
 Currently only supports METAR
 """
 
+# pylint: disable=redefined-builtin
+
+# stdlib
+from typing import List, Optional
+
 # module
-from avwx.parsing import core, translate
+import avwx.parsing.translate.base as translate_base
+import avwx.parsing.translate.taf as translate_taf
+from avwx.parsing import core
 from avwx.static.core import SPOKEN_UNITS
 from avwx.structs import Code, MetarData, Number, TafData, TafLineData, Timestamp, Units
 
 
-def ordinal(n: int) -> str:
-    """
-    Converts an int to it spoken ordinal representation
-    """
+def ordinal(n: int) -> Optional[str]:
+    """Converts an int to it spoken ordinal representation"""
     if n < 0:
         return None
     return str(n) + "tsnrhtdd"[(n / 10 % 10 != 1) * (n % 10 < 4) * n % 10 :: 4]
@@ -21,24 +26,20 @@ def ordinal(n: int) -> str:
 def wind(
     direction: Number,
     speed: Number,
-    gust: Number,
-    vardir: [Number] = None,
+    gust: Optional[Number],
+    vardir: List[Number] = None,
     unit: str = "kt",
 ) -> str:
-    """
-    Format wind details into a spoken word string
-    """
+    """Format wind details into a spoken word string"""
     unit = SPOKEN_UNITS.get(unit, unit)
-    val = translate.base.wind(
+    val = translate_base.wind(
         direction, speed, gust, vardir, unit, cardinals=False, spoken=True
     )
     return "Winds " + (val or "unknown")
 
 
 def temperature(header: str, temp: Number, unit: str = "C") -> str:
-    """
-    Format temperature details into a spoken word string
-    """
+    """Format temperature details into a spoken word string"""
     if not (temp and temp.value):
         return header + " unknown"
     unit = SPOKEN_UNITS.get(unit, unit)
@@ -47,15 +48,13 @@ def temperature(header: str, temp: Number, unit: str = "C") -> str:
 
 
 def visibility(vis: Number, unit: str = "m") -> str:
-    """
-    Format visibility details into a spoken word string
-    """
+    """Format visibility details into a spoken word string"""
     if not vis:
         return "Visibility unknown"
     if vis.value is None or "/" in vis.repr:
         ret_vis = vis.spoken
     else:
-        ret_vis = translate.base.visibility(vis, unit=unit)
+        ret_vis = translate_base.visibility(vis, unit=unit)
         if unit == "m":
             unit = "km"
         ret_vis = ret_vis[: ret_vis.find(" (")].lower().replace(unit, "").strip()
@@ -73,20 +72,18 @@ def visibility(vis: Number, unit: str = "m") -> str:
 
 
 def altimeter(alt: Number, unit: str = "inHg") -> str:
-    """
-    Format altimeter details into a spoken word string
-    """
+    """Format altimeter details into a spoken word string"""
     ret = "Altimeter "
     if not alt:
         ret += "unknown"
     elif unit == "inHg":
-        ret += core.spoken_number(str(alt.value).ljust(5, "0"))
+        ret += core.spoken_number(str(alt.value).ljust(5, "0"), True)
     elif unit == "hPa":
-        ret += core.spoken_number(str(alt.value).zfill(4))
+        ret += core.spoken_number(str(alt.value).zfill(4), True)
     return ret
 
 
-def wx_codes(codes: [Code]) -> str:
+def wx_codes(codes: List[Code]) -> str:
     """
     Format wx codes into a spoken word string
     """
@@ -100,11 +97,12 @@ def wx_codes(codes: [Code]) -> str:
 
 
 def type_and_times(
-    type: str, start: Timestamp, end: Timestamp, probability: Number = None
+    type: str,
+    start: Optional[Timestamp],
+    end: Optional[Timestamp],
+    probability: Number = None,
 ) -> str:
-    """
-    Format line type and times into the beginning of a spoken line string
-    """
+    """Format line type and times into the beginning of a spoken line string"""
     if not type:
         return ""
     start_time = start.dt.hour if start and start.dt else "an unknown start time"
@@ -122,21 +120,17 @@ def type_and_times(
 
 
 def wind_shear(shear: str, unit_alt: str = "ft", unit_wind: str = "kt") -> str:
-    """
-    Format wind shear string into a spoken word string
-    """
+    """Format wind shear string into a spoken word string"""
     unit_alt = SPOKEN_UNITS.get(unit_alt, unit_alt)
     unit_wind = SPOKEN_UNITS.get(unit_wind, unit_wind)
     return (
-        translate.taf.wind_shear(shear, unit_alt, unit_wind, spoken=True)
+        translate_taf.wind_shear(shear, unit_alt, unit_wind, spoken=True)
         or "Wind shear unknown"
     )
 
 
 def metar(data: MetarData, units: Units) -> str:
-    """
-    Convert MetarData into a string for text-to-speech
-    """
+    """Convert MetarData into a string for text-to-speech"""
     speech = []
     if data.wind_direction and data.wind_speed:
         speech.append(
@@ -159,7 +153,7 @@ def metar(data: MetarData, units: Units) -> str:
     if data.wx_codes:
         speech.append(wx_codes(data.wx_codes))
     speech.append(
-        translate.base.clouds(data.clouds, units.altitude).replace(
+        translate_base.clouds(data.clouds, units.altitude).replace(
             " - Reported AGL", ""
         )
     )
@@ -167,9 +161,7 @@ def metar(data: MetarData, units: Units) -> str:
 
 
 def taf_line(line: TafLineData, units: Units) -> str:
-    """
-    Convert TafLineData into a string for text-to-speech
-    """
+    """Convert TafLineData into a string for text-to-speech"""
     speech = []
     start = type_and_times(line.type, line.start_time, line.end_time, line.probability)
     if line.wind_direction and line.wind_speed:
@@ -190,24 +182,22 @@ def taf_line(line: TafLineData, units: Units) -> str:
     if line.wx_codes:
         speech.append(wx_codes(line.wx_codes))
     speech.append(
-        translate.base.clouds(line.clouds, units.altitude).replace(
+        translate_base.clouds(line.clouds, units.altitude).replace(
             " - Reported AGL", ""
         )
     )
     if line.turbulence:
-        speech.append(translate.taf.turb_ice(line.turbulence, units.altitude))
+        speech.append(translate_taf.turb_ice(line.turbulence, units.altitude))
     if line.icing:
-        speech.append(translate.taf.turb_ice(line.icing, units.altitude))
+        speech.append(translate_taf.turb_ice(line.icing, units.altitude))
     return start + " " + (". ".join([l for l in speech if l])).replace(",", ".")
 
 
 def taf(data: TafData, units: Units) -> str:
-    """
-    Convert TafData into a string for text-to-speech
-    """
+    """Convert TafData into a string for text-to-speech"""
     try:
-        month = data.start_time.dt.strftime(r"%B")
-        day = ordinal(data.start_time.dt.day)
+        month = data.start_time.dt.strftime(r"%B")  # type: ignore
+        day = ordinal(data.start_time.dt.day) or "Unknown"  # type: ignore
         ret = f"Starting on {month} {day} - "
     except AttributeError:
         ret = ""
