@@ -2,8 +2,12 @@
 GFS data translation handlers
 """
 
+# mypy: ignore-errors
+
 raise NotImplementedError()
 
+from typing import List
+
 import avwx.parsing.translate.base as _trans
 from avwx.structs import (
     GfsPeriod,
@@ -19,8 +23,7 @@ from avwx.structs import (
 def _gfs_shared(
     line: GfsPeriod, units: Units, dataobj: GfsPeriodTrans
 ) -> GfsPeriodTrans:
-    """
-    """
+    """"""
     data = {}
     data["temperature"] = _trans.temperature(line.temperature, units.temperature)
     data["dewpoint"] = _trans.temperature(line.dewpoint, units.temperature)
@@ -28,19 +31,15 @@ def _gfs_shared(
     return dataobj(**data)
 
 
-def translate_mav(wxdata: MavData, units: Units) -> [MavPeriodTrans]:
-    """
-    Returns translations for a TafData object
-    """
+def translate_mav(wxdata: MavData, units: Units) -> List[MavPeriodTrans]:
+    """Returns translations for a TafData object"""
     data = []
     for line in wxdata.forecast:
         _data = _gfs_shared(line, units, MavPeriodTrans)
     return data
 
 
-def translate_mex(wxdata: MexData, units: Units) -> [MexPeriodTrans]:
-    """
-    Returns translations for a TafData object
-    """
+def translate_mex(wxdata: MexData, units: Units) -> List[MexPeriodTrans]:
+    """Returns translations for a TafData object"""
     data = []
     return data
